/*******************************************************************************
 *
 *
 *    WashingtonDC Dreamcast Emulator
 *    Copyright (C) 2024 snickerbockers
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 ******************************************************************************/

#ifndef CDI_H
#define CDI_H

struct cdi_track {
    /*
     * start of the pregap before the track.  You'll need to add
     * (pregap_len * sector_sz) to get to the actual start of the track.
     */
    unsigned start;
    unsigned pregap_len;
    unsigned track_len;
    unsigned sector_sz;
    unsigned start_lba;

    unsigned ctrl;

    /*
     * this is always pregap_len + track_len, but it's a separate field in the
     * .cdi so might as well take it seriously in case there are any cdi files
     * out there with weird padding or something.
     */
    unsigned total_len;
};

struct cdi_session {
    unsigned n_tracks;
    unsigned first_track;
    struct cdi_track *tracks;
};

typedef struct cdi_file {
    FILE *stream;
    unsigned n_sessions;
    struct cdi_session *sessions;
} cdi_file;

cdi_file* cdi_load(char const *path);

extern struct disc_intf const cdi_intf;

#endif
